#!/usr/bin/env bash
#
# Check that the official org-mode parser and this implementation of an org-mode parser agree on how the sample org-mode documents should be parsed.
set -euo pipefail
IFS=$'\n\t'
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
cd "$DIR"

: ${org_dir:="$DIR/../org_mode_samples"}
: ${compare_bin:="$DIR/../target/debug/org_compare"}

test_files=$(find $org_dir -type f -name '*.org' | sort)

cargo build --bin org_compare

pass=0
fail=0


while read test_file; do
    print_path=$(realpath --relative-to="$org_dir" "$test_file")
    set +e
    diff_results=$("$compare_bin" "$test_file")
    diff_status=$?
    set -e
    if [ $diff_status -eq 0 ]; then
        echo "GOOD   $print_path"
        pass=$((pass + 1))
    else
        echo "BAD    $print_path"
        fail=$((fail + 1))
    fi
done<<<"$test_files"

total=$((pass + fail))
(>&2 echo "Tests passed: $pass/$total")
